<?php

namespace BitGoblin\Colossus\Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Routing\RouteContext;
use Slim\Views\Twig;
use BitGoblin\Colossus\Models\Result;
use BitGoblin\Colossus\Models\Test;

class ResultController extends Controller {

  public function getList(Request $request, Response $response): Response {
    $results = Result::orderByDesc('updated_at')->get();

    $view = Twig::fromRequest($request);
    return $view->render($response, 'result/list.twig', [
      'results' => $results,
    ]);
  }

  public function getAdd(Request $request, Response $response): Response {
    $tests = Test::all();

    $view = Twig::fromRequest($request);
    return $view->render($response, 'result/add.twig', [
      'tests' => $tests,
    ]);
  }

  public function postAdd(Request $request, Response $response): Response {
    $params = (array)$request->getParsedBody();

    $result = new Result;
    $result->test_id = $params['result_test'];
    $result->component = $params['result_component'];
    $result->benchmark = $params['result_benchmark'];
    $result->type = $params['result_type'];
    $result->average = $params['result_avg'];
    $result->minimum = $params['result_min'];
    $result->maximum = $params['result_max'];

    $result->save();

    // redirect the user back to the home page
    $routeContext = RouteContext::fromRequest($request);
    $routeParser = $routeContext->getRouteParser();
    return $response
      ->withHeader('Location', $routeParser->urlFor('test.view', [
        'test_id' => $result->test_id
      ]))
      ->withStatus(302);
  }

}
